==> zio-aws-serverlessapplicationrepository_2.12-7.21.15.7-sources.jar: zio/aws/serverlessapplicationrepository/model/GetApplicationPolicyRequest.scala <==
package zio.aws.serverlessapplicationrepository.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.serverlessapplicationrepository.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class GetApplicationPolicyRequest(applicationId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.serverlessapplicationrepository.model.GetApplicationPolicyRequest = {
    import GetApplicationPolicyRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.serverlessapplicationrepository.model.GetApplicationPolicyRequest
      .builder()
      .applicationId(applicationId: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.serverlessapplicationrepository.model.GetApplicationPolicyRequest.ReadOnly =
    zio.aws.serverlessapplicationrepository.model.GetApplicationPolicyRequest
      .wrap(buildAwsValue())
}
object GetApplicationPolicyRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.serverlessapplicationrepository.model.GetApplicationPolicyRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.serverlessapplicationrepository.model.GetApplicationPolicyRequest =
      zio.aws.serverlessapplicationrepository.model
        .GetApplicationPolicyRequest(applicationId)
    def applicationId: __string
    def getApplicationId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(applicationId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.serverlessapplicationrepository.model.GetApplicationPolicyRequest
  ) extends zio.aws.serverlessapplicationrepository.model.GetApplicationPolicyRequest.ReadOnly {
    override val applicationId: __string = impl.applicationId(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.serverlessapplicationrepository.model.GetApplicationPolicyRequest
  ): zio.aws.serverlessapplicationrepository.model.GetApplicationPolicyRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-serverlessapplicationrepository_2.13-5.17.102.7-sources.jar: zio/aws/serverlessapplicationrepository/model/GetApplicationPolicyRequest.scala <==
package zio.aws.serverlessapplicationrepository.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.serverlessapplicationrepository.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class GetApplicationPolicyRequest(applicationId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.serverlessapplicationrepository.model.GetApplicationPolicyRequest = {
    import GetApplicationPolicyRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.serverlessapplicationrepository.model.GetApplicationPolicyRequest
      .builder()
      .applicationId(__string.unwrap(applicationId): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.serverlessapplicationrepository.model.GetApplicationPolicyRequest.ReadOnly =
    zio.aws.serverlessapplicationrepository.model.GetApplicationPolicyRequest
      .wrap(buildAwsValue())
}
object GetApplicationPolicyRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.serverlessapplicationrepository.model.GetApplicationPolicyRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.serverlessapplicationrepository.model.GetApplicationPolicyRequest =
      zio.aws.serverlessapplicationrepository.model
        .GetApplicationPolicyRequest(applicationId)
    def applicationId: __string
    def getApplicationId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(applicationId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.serverlessapplicationrepository.model.GetApplicationPolicyRequest
  ) extends zio.aws.serverlessapplicationrepository.model.GetApplicationPolicyRequest.ReadOnly {
    override val applicationId: __string =
      zio.aws.serverlessapplicationrepository.model.primitives
        .__string(impl.applicationId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.serverlessapplicationrepository.model.GetApplicationPolicyRequest
  ): zio.aws.serverlessapplicationrepository.model.GetApplicationPolicyRequest.ReadOnly =
    new Wrapper(impl)
}
